"eMap1" <-
function(me, mm1, mm2=NULL, output.tag, p.cut, cis.only=FALSE, cis.distance=1e6, 
  eChr=NULL, ePos=NULL, mChr=NULL, mPos=NULL, tol=1e-7, nna.percent=0.75)
{
    if(is.vector(me)){
        ncol.me = length(me)
        nrow.me = 1
        if(var(me) < 1e-10){
        	warning("Variance of me is 0\n")
        }
    }else{
        ncol.me = ncol(me)
        nrow.me = nrow(me)
        
        vme = apply(me, 1, var)
        wme = which(vme < 1e-10)
        
        if(length(wme) > 0){
        	warning("These rows in me have zero variances: ", wme, "\n")
        }
    }

    if(is.vector(mm1)){
        ncol.mm = length(mm1)
        nrow.mm = 1
        
        if(var(mm1) < 1e-10){
        	warning("Variance of mm1 is 0\n")
        }
    }else{
        ncol.mm = ncol(mm1)
        nrow.mm = nrow(mm1)
        
        vmm1 = apply(mm1, 1, var)
        wmm1 = which(vmm1 < 1e-10)
        
        if(length(wmm1) > 0){
        	warnStr = "rows in mm1 have zero variances"
        	warnStr = sprintf("These %d %s: \n", length(wmm1), warnStr)
        	warning(warnStr, paste(wmm1, collapse=" "), "\n")
        }
    }

    if(!is.null(mm2)){
      if(is.vector(mm2)){
        
        if(ncol.mm != length(mm1)){
          stop("mm2 and mm1 have different lengths\n")
        }
        
        if(var(mm2) < 1e-10){
          stop("Variance of mm2 is 0\n")
        }
      }else{
        if(ncol.mm != ncol(mm1) || nrow.mm != nrow(mm1)){
          stop("mm2 and mm1 have different dimensions\n")
      	}
      	
        vmm2 = apply(mm2, 1, var)
        wmm2 = which(vmm2 < 1e-10)
        
        if(length(wmm2) > 0){
        	warnStr = "rows in mm2 have zero variances"
        	warnStr = sprintf("These %d %s: \n", length(wmm2), warnStr)
        	warning(warnStr, paste(wmm2, collapse=" "), "\n")
        }
      }
    }
    
    if(ncol.mm != ncol.me){
        stop("mm and me have different number of columns!")
    }
    
    if(cis.only){
      if(!is.numeric(eChr) || length(eChr) != nrow.me){
        stop(sprintf("eChr must be a numeric vector of length %d\n", nrow.me))
      }
      if(!is.numeric(ePos) || length(ePos) != nrow.me){
        stop(sprintf("ePos must be a numeric vector of length %d\n", nrow.me))
      }
      if(!is.numeric(mChr) || length(mChr) != nrow.mm){
        stop(sprintf("mChr must be a numeric vector of length %d\n", nrow.mm))
      }
      if(!is.numeric(mPos) || length(mPos) != nrow.mm){
        stop(sprintf("mPos must be a numeric vector of length %d\n", nrow.mm))
      }
    }
        
    dims = numeric(4)
    dims[1] = nrow.me
    dims[2] = nrow.mm
    dims[3] = ncol.me
    dims[4] = as.numeric(!is.null(mm2))
  
    succeed = 0
    
    output = character(2)
    output[1] = sprintf("%s_eqtl.txt", output.tag)
    output[2] = sprintf("%s_freq.txt", output.tag)
    
    me.na = is.na(me)    
    me[me.na] = 0
    
    mm1.na = is.na(mm1)
    mm1[mm1.na] = 0
    
    if(is.null(mm2)){
      mm2 = 0.0
      mm2.na = 1
    }else{
      mm2.na = is.na(mm2)
      mm2[mm2.na] = 0
    }
    
    Z = .C("lmEQTL", as.integer(dims), as.double(me), as.double(mm1), 
            as.double(mm2), as.integer(!me.na), as.integer(!mm1.na), 
            as.integer(!mm2.na), as.character(output), as.double(p.cut), 
            as.integer(cis.only), as.integer(cis.distance), as.integer(eChr), 
            as.integer(ePos), as.integer(mChr), as.integer(mPos), as.double(tol), 
            as.double(nna.percent), as.integer(succeed), PACKAGE="eMap")
    
    me[me.na] = NA
    mm1[mm1.na] = NA
    if(!is.null(mm2)){ mm2[mm2.na] = NA }
    
    Z[[length(Z)]]
}
