\name{eMap1}
\alias{eMap1}
\title{ linear regression for eQTL with upto two genetic effects }
\description{
  Identify significant eQTL by simple linear regression. Each model takes up to two covaraites.
}

\usage{
eMap1(me, mm1, mm2=NULL, output.tag, p.cut, cis.only=FALSE, cis.distance=1e6, 
  eChr=NULL, ePos=NULL, mChr=NULL, mPos=NULL, tol=1e-7,
  nna.percent=0.75)
}
\arguments{
  \item{me}{ matrix of gene expression. Each row corresponds to one gene. }
  \item{mm1}{ matrix of marker genotype. Each row corresponds to one marker. Must has the same number of colums as me. }
  \item{mm2}{ second matrix of marker genotype. For example, mm1 is the codeing of genotype by additive effect, and mm2 is the coding of genotype by dominant effect. Another example is for eQTL mapping of allele-specific copy number. mm1 could be the overall copy number and mm2 could be the the diffence between the number of two alleles.  }
  \item{output.tag}{ output file name tag }
  \item{p.cut}{ p-value cut-off for p-value of the slope. }
  \item{cis.only}{ whether examine cis-linkage only. }
  \item{cis.distance}{ if the distance between a gene and a marker
   is smaller than cis.distance, we call it as cis-linkage. }
  \item{eChr}{ chromosomes of gene expression traits, must be
   a vector of integers, which means sex chromosomes (X, Y) need
   to be coded as numbers }
  \item{ePos}{ positions of gene expression traits, must be
   a vector of integers}
  \item{mChr}{ chromosomes of markers, must be a vector of integers,
   which means sex chromosomes (X, Y) need to be coded as numbers }
  \item{mPos}{ positions of markers, must be a vector of integers}
  \item{tol}{ components of model matrix are discarded if the ratio
   of singular values $s_i/s_0$ falls below tol. }
  \item{nna.percent}{ minimum percentage of non-missing values. }
}
\note{
  if mm2 is not null the p-value of each marker is calclated by an F test with two degree of freedoms to accoutn for the effects of the genetic variation in both mm1 and mm2. 
}
\value{
The function return 1 if no error occurs.
 The results are written into
 two output files: one file for mapping result, including gene ID,
 marker ID, regression coefficient, and p-value;
 the other file is a frequency table of the p-values.}
\examples{
  data(simuD)
  me  = simuD$expression
  mm  = simuD$genotype
  sex = simuD$sex
  
  eMap1(me, mm, output.tag="test_lmEQTL", p.cut=0.01)
}
\author{ Wei Sun wsun@bios.unc.edu }
\keyword{ methods }
